<?php
session_start();
require_once('config.php');
require_once('dbutils.php');
require_once('locationfuncs.php');
require_once('externaldbfuncs.php');

$masterdb = new GenericSqliteTable("var/master.db","master");
$areadb = new GenericSqliteTable("var/area.db","area");

$listAreas = $areadb->GetKeys();
$nameCol = GetConfigOption('nameCol');

if(GetConfigOption('enableArea'))
{
	if(isset($_GET['area'])) $_SESSION['area'] = $_GET['area'];
	if(!isset($_GET['area']) and isset($_SESSION['area'])) $_GET['area'] = $_SESSION['area'];
	if(!isset($_GET['area'])) $_GET['area'] = $listAreas[0];
	$ids = $areadb[$_GET['area']];
}
else
{
	$ids = $masterdb->GetKeys();
}


//Find marker locations and external links
$bestlocs = array();
$bestosm = array();
$markercol = array();
$minlat = Null; $maxlat = Null; $minlon = Null; $maxlon = Null;
foreach($ids as $id)
{
	$ret = GetBestLocation($id);
	$bestlocs[$id] = $ret;
	$ret = GetBestOsmLink($id);
	$bestosm[$id] = $ret;
	//print_r($bestlocs[$id]);

	//Determine marker status
	$located = 0;
	$presentOsm = 0;
	if($bestlocs[$id][0] != Null and !$bestlocs[$id][1])
		$located = 1;
	if(!$located and $bestosm[$id][0] != Null)
		$presentOsm = 1;

	//Assign colour
	$markercol[$id] = "red";
	if($presentOsm) $markercol[$id] = "yellow";
	if($located) $markercol[$id] = "green";

	//Update bounding box
	if($bestlocs[$id][0]!==null)
	{
		$lat = $bestlocs[$id][0][0]; $lon = $bestlocs[$id][0][1];
		if(is_null($minlat) or $minlat > $lat) $minlat = $lat;
		if(is_null($maxlat) or $maxlat < $lat) $maxlat = $lat;
		if(is_null($minlon) or $minlon > $lon) $minlon = $lon;
		if(is_null($maxlon) or $maxlon < $lon) $maxlon = $lon;
	}
}
$midlat = 0.5 * ($minlat + $maxlat);
$midlon = 0.5 * ($minlon + $maxlon);

//If bounds not set, zoom out to entire world
$initialZoom = GetConfigOption('initialZoomOverview');;
if($minlat === Null or $minlon === Null)
{
	$midlat = 0.;
	$midlon = 0.;
	$initialZoom = 2;
}

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<!--
Design by Free CSS Templates
http://www.freecsstemplates.org
Released for free under a Creative Commons Attribution 2.5 License

Name       : Tomatoes
Description: A two-column, fixed-width design for 1024x768 screen resolutions.
Version    : 1.0
Released   : 20110301

-->

<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<title><?php echo GetConfigOption('overallTitle').", ".GetConfigOption('subTitle');?></title>
	<meta name="keywords" content="" />
	<meta name="description" content="" />
	<link href="style.css" rel="stylesheet" type="text/css" media="screen" />
	<script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=false"></script>
	<script type="text/javascript" src="googlemap.js"></script>
	<link href="atomfeed.php" type="application/atom+xml" rel="alternate" title="Sitewide ATOM Feed" />
</head>
<body onload="initializeMap(<?php echo $midlat.",".$midlon.",".$initialZoom; ?>,'osm'); Test();">
<div id="wrapper">
	<div id="header">
		<div id="menu">
			<ul>
			<?php $pageCatExplore = 1;
			require('topbar.php'); ?>
			</ul>
		</div>
		<!-- end #menu -->
	</div>
	<div id="logo">
		<h1><a href="#"><?php echo GetConfigOption('overallTitle');?></a></h1>
		<p><em><?php echo GetConfigOption('subTitle');?></em></p>
	</div>
	<hr />
	<!-- end #logo -->
	<div id="page">
		<div id="page-bgtop">
			<div id="content">
				<div class="post">
					<h2 class="title"><a href="#"><?php echo GetConfigOption('mapTitle');?></a></h2>
<?php if(GetConfigOption('enableArea')){?>
<form id="areaselect" method="GET">
<select name="area">
<?php
sort($listAreas);
foreach($listAreas as $a)
{
	if(strlen($a)==0) continue; //Ignore empty areas. Not sure where this is coming from.
	echo "<option ";
	if($a == $_GET['area']) echo 'selected="yes"';
	echo ">".htmlspecialchars($a)."</option>\n";
}

?>
</select>
<input type="submit" value="Go" />
</form>
<?php } //End of area select form ?>

<div id="map_canvas" style="width: 100%; height: 400px;"></div>
<p>Green: position accurately known, Yellow: present in OSM, Red: Missing/inaccurate POI.</p>
<?php echo GetConfigOption('frontPageText'); ?>

<script type="text/javascript">
// <![CDATA[
function Test()
{
	$windows = [];
	var infowindow = new google.maps.InfoWindow({});
<?php

foreach($ids as $id)
{
	$record = $masterdb[$id];
	list($osmtype,$osmid) = $bestosm[$id];
	list($pos,$rough) = $bestlocs[$id];
	if($pos == Null) continue;
?>
	var latLng = new google.maps.LatLng(<?php echo $pos['0']; ?>, <?php echo $pos['1']; ?>);
	var markerImage = new google.maps.MarkerImage('img/map_marker_<?php echo $markercol[$id];?>.png',null,null,new google.maps.Point(10, 34));

	var marker = new google.maps.Marker({
	  position: latLng,
	  title: "<?php echo htmlspecialchars($record[$nameCol]); ?>",
	  map: map,
	  draggable: false,
	  icon: markerImage
	});
	//marker.setIcon('map_marker_<?php echo $markercol[$id];?>.png')

	window["marker<?php echo $id;?>"] = marker;

	google.maps.event.addListener(marker, 'click', function() {
		infowindow.setContent("<p><?php echo htmlspecialchars($record[$nameCol]); ?><br/><a href='details.php?id=<?php echo $id;?>'>View Details</a> <a href='markposition.php?basemap=sv&id=<?php echo $id; ?>'>Mark on OS</a></p>"); 
		infowindow.open(map,marker<?php echo $id;?>);
	});
<?php
}
?>
}
// ]]>
</script>



				</div>

			</div>
			<!-- end #content -->
			<div id="sidebar">
				<ul>
					<?php require('sidebar.php'); ?>


<?php
//*****************************
//Generate Textual List of POIs
//*****************************
/*
//print_r($ids);

echo "<li><ul>\n";

foreach($ids as $ind => $id)
{
	if($ind == "key") continue; //Avoid a quirk of generic sqlite class :)
	$record = $masterdb[$id];
	echo "<li>";
	//echo $id;
	echo "<img src=\"img/button-".$markercol[$id].".png\" height='16px' width='16px' alt=\"".$markercol[$id]." button\" />";	
	echo " <a href=\"details.php?id=".htmlspecialchars($id)."\">".htmlspecialchars($record[$nameCol]);
	echo "</a>";
	if($bestosm[$id][0]!=null)
	{
		echo " <a href=\"http://www.openstreetmap.org/browse/".htmlspecialchars($bestosm[$id][0])."/".$bestosm[$id][1]."\"><img src=\"img/link.png\" alt=\"Link image\" height='16px' width='16px'/></a>\n";
	}
	//print_r(GetBestLocation($id));
	//print_r(GetBestOsmLink($id));
	echo "</li>\n";
	
}

echo "</ul></li>\n";*/
?>


				</ul>
			</div>
			<!-- end #sidebar -->
			<div style="clear: both;">&nbsp;</div>
		</div>
	</div>
	<!-- end #page -->
	<div id="footer">
		

<?php
echo GetConfigOption('footer');
?>

	</div>
	<!-- end #footer -->
</div>
</body>
</html>
